@@ -12,7 +12,7 @@
 #=======================================================================
 package PDF::API2::Basic::PDF::Dict;
 
-our $VERSION = '2.016';
+our $VERSION = '2.017';
 
 use base 'PDF::API2::Basic::PDF::Objind';
 
@@ -222,110 +222,6 @@ sub outobjdeep
 
 }
 
-sub outxmldeep
-{
-    my ($self, $fh, $pdf, %opts) = @_;
-    my ($key, $val, $f, @filts);
-    my ($loc, $str, %specs, $len);
-
-    $opts{-xmlfh}->print("<Dict>\n");
-    foreach ('Type', 'Subtype')
-    {
-        $specs{$_} = 1;
-        if (defined $self->{$_})
-        {
-            $opts{-xmlfh}->print("<Key id=\"$_\">");
-            $self->{$_}->outxml($fh, $pdf, %opts);
-            $opts{-xmlfh}->print("</Key>\n");
-        }
-    }
-    while (($key, $val) = each %{$self})
-    {
-        next if ($key =~ m/^[\s\-]/o || $specs{$key});
-        next if ($val eq '');
-    $key = PDF::API2::Basic::PDF::Name::string_to_name ($key, $pdf);
-        $opts{-xmlfh}->print("<Key id=\"$key\">");
-        $val->outxml($fh, $pdf, %opts);
-        $opts{-xmlfh}->print("</Key>\n");
-    }
-    $opts{-xmlfh}->print("</Dict>\n");
-
-#now handle the stream (if any)
-    if (defined $self->{' streamloc'} && !defined $self->{' stream'})
-    {                                   # read a stream if infile
-        $loc = $fh->tell;
-        $self->read_stream;
-        $fh->seek($loc, 0);
-    }
-
-    if (!$self->{' nofilt'}
-            && (defined $self->{' stream'} || defined $self->{' streamfile'})
-            && defined $self->{'Filter'})
-    {
-        my ($hasflate) = -1;
-        my ($temp, $i, $temp1);
-
-        for ($i = 0; $i < scalar @{$self->{'Filter'}{' val'}}; $i++)
-        {
-            $temp = $self->{'Filter'}{' val'}[$i]->val;
-            if ($temp eq 'LZWDecode')               # hack to get around LZW patent
-            {
-                if ($hasflate < -1)
-                {
-                    $hasflate = $i;
-                    next;
-                }
-                $temp = 'FlateDecode';
-                $self->{'Filter'}{' val'}[$i]{'val'} = $temp;      # !!!
-            } elsif ($temp eq 'FlateDecode')
-            { $hasflate = -2; }
-            $temp1 = "PDF::API2::Basic::PDF::$temp";
-            push (@filts, $temp1->new);
-        }
-        splice(@{$self->{'Filter'}{' val'}}, $hasflate, 1) if ($hasflate > -1);
-    }
-
-    if (defined $self->{' stream'})
-    {
-        $opts{-xmlfh}->print("<Stream>\n");
-        $loc = $fh->tell;
-        $str = $self->{' stream'};
-        if ($self->{' nofilt'})
-        {
-            foreach $f (@filts)
-            { $str = $f->infilt($str, 1); }
-        }
-        $opts{-xmlfh}->print($str);
-        $opts{-xmlfh}->print("</Stream>\n");
-    } elsif (defined $self->{' streamfile'})
-    {
-    	my $DICTFH;
-        open($DICTFH, $self->{' streamfile'}) || die "Unable to open $self->{' streamfile'}";
-        binmode($DICTFH,':raw');
-        $opts{-xmlfh}->print("<Stream>\n");
-        while (read($DICTFH, $str, 4096))
-        {
-            if ($self->{' nofilt'})
-            {
-                foreach $f (@filts)
-                { $str = $f->infilt($str, 0); }
-            }
-        $opts{-xmlfh}->print($str);
-        }
-        close($DICTFH);
-        if ($self->{' nofilt'})
-        {
-            $str = '';
-            foreach $f (@filts)
-            { $str = $f->infilt($str, 1); }
-        $opts{-xmlfh}->print($str);
-        }
-
-        $opts{-xmlfh}->print("</Stream>\n");
-    }
-}
-
-
 =head2 $d->read_stream($force_memory)
 
 Reads in a stream from a PDF file. If the stream is greater than
