@@ -14,7 +14,7 @@
 #=======================================================================
 package PDF::API2::Basic::PDF::File;
 
-our $VERSION = '2.016';
+our $VERSION = '2.017';
 
 =head1 NAME
 
@@ -1345,81 +1345,6 @@ sub _new
     $self;
 }
 
-sub save_xml
-{
-    my ($self,$fh) = @_;
-    my ($tdict, $t, $buf, $ver);
-
-    $fh->print("<Pdf>\n");
-
-    $tdict = PDFDict();
-    $tdict->{'Prev'} = PDFNum($self->{' loc'}) if ($self->{' loc'});
-    $tdict->{'Size'} = $self->{'Size'} || PDFNum(1);
-    $tdict->{'Info'} = $self->{'Info'};
-    if (defined $self->{' newroot'})
-    { $tdict->{'Root'} = $self->{' newroot'}; }
-    else
-    { $tdict->{'Root'} = $self->{'Root'}; }
-    $tdict->{'Size'} = $self->{'Size'};
-
-    foreach $t (grep ($_ !~ m/^\s/o, keys %$self))
-    { $tdict->{$t} = $self->{$t} unless defined $tdict->{$t}; }
-
-    $self->out_xml($tdict,$fh);
-    $fh->print("</Pdf>\n");
-}
-
-sub ship_xml
-{
-    my ($self, $fh, @objs) = @_;
-    my ($n, $objind, $i, $j);
-    my ($objnum, $objgen);
-
-    @objs = @{$self->{' outlist'}} unless (scalar @objs > 0);
-    foreach $objind (@objs)
-    {
-        next unless $objind->is_obj($self);
-        $j = -1;
-        for ($i = 0; $i < scalar @{$self->{' outlist'}}; $i++)
-        {
-            if ($self->{' outlist'}[$i] eq $objind)
-            {
-                $j = $i;
-                last;
-            }
-        }
-        next if ($j < 0);
-        splice(@{$self->{' outlist'}}, $j, 1);
-        delete $self->{' outlist_cache'}{$objind};
-        next if grep {$_ eq $objind} @{$self->{' free'}};
-
-        ($objnum, $objgen) = @{$self->{' objects'}{$objind->uid}}[0..1];
-        $fh->printf("<Object id=\"%d %d\">\n", $objnum, $objgen);
-        $objind->outxmldeep($fh, $self, 'objnum' => $objnum, 'objgen' => $objgen,-xmlfh=>$fh);
-        $fh->print("</Object>\n");
-
-        # Note that we've output this obj, not forgetting to update the cache
-        # of whats printed.
-        unless (exists $self->{' printed_cache'}{$objind})
-        {
-            push( @{$self->{' printed'}}, $objind );
-            $self->{' printed_cache'}{$objind}++;
-        }
-    }
-    $self;
-}
-
-sub out_xml
-{
-    my ($self, $tdict, $fh) = @_;
-    my ($objind, $j, $i, $iend, @xreflist, $first, $k, $xref, $tloc, @freelist);
-    my (%locs, $size);
-
-    while (@{$self->{' outlist'}})
-    { $self->ship_xml($fh); }
-
-}
-
 1;
 
 =head1 AUTHOR
