@@ -1,7 +1,7 @@
 # Literal PDF Object for Dirty Hacks ...
 package PDF::API2::Basic::PDF::Literal;
 
-our $VERSION = '2.016';
+our $VERSION = '2.017';
 
 use base 'PDF::API2::Basic::PDF::Objind';
 
@@ -80,12 +80,6 @@ sub outobjdeep
     }
 }
 
-sub outxmldeep
-{
-    my ($self, $fh, $pdf, %opts) = @_;
-    $opts{-xmlfh}->print("<Literal>NOT HANDLED HERE.</Literal>\n");
-}
-
 sub val
 { $_[0]; }
 
