@@ -12,7 +12,7 @@
 #=======================================================================
 package PDF::API2::Basic::PDF::Number;
 
-our $VERSION = '2.016';
+our $VERSION = '2.017';
 
 use base 'PDF::API2::Basic::PDF::String';
 
@@ -44,10 +44,4 @@ sub as_pdf {
     return $_[0]->{'val'};
 }
 
-sub outxmldeep {
-    my ($self, $fh, $pdf, %opts) = @_;
-
-    $opts{'-xmlfh'}->print('<Number>' . $self->val() . "</Number>\n");
-}
-
 1;
