@@ -1,6 +1,6 @@
 package PDF::API2::Resource::ColorSpace::Indexed::ACTFile;
 
-our $VERSION = '2.016';
+our $VERSION = '2.017';
 
 use base 'PDF::API2::Resource::ColorSpace::Indexed';
 
@@ -11,7 +11,7 @@ no warnings qw[ deprecated recursion uninitialized ];
 
 =head1 NAME
 
-PDF::API2::Resource::ColorSpace::Index::ACTFile
+PDF::API2::Resource::ColorSpace::Indexed::ACTFile
 
 =head1 METHODS
 
